summaryrefslogtreecommitdiffstats
path: root/kstyles/highcolor/highcolor.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kstyles/highcolor/highcolor.cpp')
-rw-r--r--kstyles/highcolor/highcolor.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kstyles/highcolor/highcolor.cpp b/kstyles/highcolor/highcolor.cpp
index cbfc2699c..318b0f207 100644
--- a/kstyles/highcolor/highcolor.cpp
+++ b/kstyles/highcolor/highcolor.cpp
@@ -1185,7 +1185,7 @@ void HighColorStyle::tqdrawControl( TQ_ControlElement element,
// Make the label indicate if the button is a default button or not
if ( active || button->isDefault() ) {
// Draw "fake" bold text - this enables the font metrics to remain
// the same as computed in TQPushButton::tqsizeHint(), but gives
// a reasonable bold effect.
int i;
@@ -1875,8 +1875,8 @@ TQSize HighColorStyle::tqsizeFromContents( ContentsType contents,
int w = contentSize.width(), h = contentSize.height();
if ( mi->custom() ) {
- w = mi->custom()->tqsizeHint().width();
- h = mi->custom()->tqsizeHint().height();
+ w = mi->custom()->sizeHint().width();
+ h = mi->custom()->sizeHint().height();
if ( ! mi->custom()->fullSpan() )
h += 2*itemVMargin + 2*itemFrame;
}
@@ -1185,7 +1185,7 @@ void HighColorStyle::tqdrawControl( TQ_ControlElement element,
if ( active || button->isDefault() ) {
// Draw "fake" bold text - this enables the font metrics to remain
- // the same as computed in TQPushButton::tqsizeHint(), but gives
+ // the same as computed in TQPushButton::sizeHint(), but gives
// a reasonable bold effect.
int i;